@@ -15,6 +15,8 @@
 # limitations under the License.
 #
 
+
+
 from google.net.proto import ProtocolBuffer
 import array
 import dummy_thread as thread
@@ -26,6 +28,7 @@ from google.appengine.api.api_base_pb import *
 import google.appengine.api.api_base_pb
 class UserServiceError(ProtocolBuffer.ProtocolMessage):
 
+
   OK           =    0
   REDIRECT_URL_TOO_LONG =    1
   NOT_ALLOWED  =    2
@@ -64,7 +67,11 @@ class UserServiceError(ProtocolBuffer.ProtocolMessage):
 
   def ByteSize(self):
     n = 0
-    return n + 0
+    return n
+
+  def ByteSizePartial(self):
+    n = 0
+    return n
 
   def Clear(self):
     pass
@@ -72,9 +79,14 @@ class UserServiceError(ProtocolBuffer.ProtocolMessage):
   def OutputUnchecked(self, out):
     pass
 
+  def OutputPartial(self, out):
+    pass
+
   def TryMerge(self, d):
     while d.avail() > 0:
       tt = d.getVarInt32()
+
+
       if (tt == 0): raise ProtocolBuffer.ProtocolBufferDecodeError
       d.skipData(tt)
 
@@ -96,6 +108,7 @@ class UserServiceError(ProtocolBuffer.ProtocolMessage):
     0: ProtocolBuffer.Encoder.NUMERIC,
   }, 0, ProtocolBuffer.Encoder.MAX_TYPE)
 
+
   _STYLE = """"""
   _STYLE_CONTENT_TYPE = """"""
 class CreateLoginURLRequest(ProtocolBuffer.ProtocolMessage):
@@ -180,6 +193,15 @@ class CreateLoginURLRequest(ProtocolBuffer.ProtocolMessage):
     if (self.has_federated_identity_): n += 1 + self.lengthString(len(self.federated_identity_))
     return n + 1
 
+  def ByteSizePartial(self):
+    n = 0
+    if (self.has_destination_url_):
+      n += 1
+      n += self.lengthString(len(self.destination_url_))
+    if (self.has_auth_domain_): n += 1 + self.lengthString(len(self.auth_domain_))
+    if (self.has_federated_identity_): n += 1 + self.lengthString(len(self.federated_identity_))
+    return n
+
   def Clear(self):
     self.clear_destination_url()
     self.clear_auth_domain()
@@ -195,6 +217,17 @@ class CreateLoginURLRequest(ProtocolBuffer.ProtocolMessage):
       out.putVarInt32(26)
       out.putPrefixedString(self.federated_identity_)
 
+  def OutputPartial(self, out):
+    if (self.has_destination_url_):
+      out.putVarInt32(10)
+      out.putPrefixedString(self.destination_url_)
+    if (self.has_auth_domain_):
+      out.putVarInt32(18)
+      out.putPrefixedString(self.auth_domain_)
+    if (self.has_federated_identity_):
+      out.putVarInt32(26)
+      out.putPrefixedString(self.federated_identity_)
+
   def TryMerge(self, d):
     while d.avail() > 0:
       tt = d.getVarInt32()
@@ -207,6 +240,8 @@ class CreateLoginURLRequest(ProtocolBuffer.ProtocolMessage):
       if tt == 26:
         self.set_federated_identity(d.getPrefixedString())
         continue
+
+
       if (tt == 0): raise ProtocolBuffer.ProtocolBufferDecodeError
       d.skipData(tt)
 
@@ -240,6 +275,7 @@ class CreateLoginURLRequest(ProtocolBuffer.ProtocolMessage):
     3: ProtocolBuffer.Encoder.STRING,
   }, 3, ProtocolBuffer.Encoder.MAX_TYPE)
 
+
   _STYLE = """"""
   _STYLE_CONTENT_TYPE = """"""
 class CreateLoginURLResponse(ProtocolBuffer.ProtocolMessage):
@@ -286,6 +322,13 @@ class CreateLoginURLResponse(ProtocolBuffer.ProtocolMessage):
     n += self.lengthString(len(self.login_url_))
     return n + 1
 
+  def ByteSizePartial(self):
+    n = 0
+    if (self.has_login_url_):
+      n += 1
+      n += self.lengthString(len(self.login_url_))
+    return n
+
   def Clear(self):
     self.clear_login_url()
 
@@ -293,12 +336,19 @@ class CreateLoginURLResponse(ProtocolBuffer.ProtocolMessage):
     out.putVarInt32(10)
     out.putPrefixedString(self.login_url_)
 
+  def OutputPartial(self, out):
+    if (self.has_login_url_):
+      out.putVarInt32(10)
+      out.putPrefixedString(self.login_url_)
+
   def TryMerge(self, d):
     while d.avail() > 0:
       tt = d.getVarInt32()
       if tt == 10:
         self.set_login_url(d.getPrefixedString())
         continue
+
+
       if (tt == 0): raise ProtocolBuffer.ProtocolBufferDecodeError
       d.skipData(tt)
 
@@ -324,6 +374,7 @@ class CreateLoginURLResponse(ProtocolBuffer.ProtocolMessage):
     1: ProtocolBuffer.Encoder.STRING,
   }, 1, ProtocolBuffer.Encoder.MAX_TYPE)
 
+
   _STYLE = """"""
   _STYLE_CONTENT_TYPE = """"""
 class CreateLogoutURLRequest(ProtocolBuffer.ProtocolMessage):
@@ -389,6 +440,14 @@ class CreateLogoutURLRequest(ProtocolBuffer.ProtocolMessage):
     if (self.has_auth_domain_): n += 1 + self.lengthString(len(self.auth_domain_))
     return n + 1
 
+  def ByteSizePartial(self):
+    n = 0
+    if (self.has_destination_url_):
+      n += 1
+      n += self.lengthString(len(self.destination_url_))
+    if (self.has_auth_domain_): n += 1 + self.lengthString(len(self.auth_domain_))
+    return n
+
   def Clear(self):
     self.clear_destination_url()
     self.clear_auth_domain()
@@ -400,6 +459,14 @@ class CreateLogoutURLRequest(ProtocolBuffer.ProtocolMessage):
       out.putVarInt32(18)
       out.putPrefixedString(self.auth_domain_)
 
+  def OutputPartial(self, out):
+    if (self.has_destination_url_):
+      out.putVarInt32(10)
+      out.putPrefixedString(self.destination_url_)
+    if (self.has_auth_domain_):
+      out.putVarInt32(18)
+      out.putPrefixedString(self.auth_domain_)
+
   def TryMerge(self, d):
     while d.avail() > 0:
       tt = d.getVarInt32()
@@ -409,6 +476,8 @@ class CreateLogoutURLRequest(ProtocolBuffer.ProtocolMessage):
       if tt == 18:
         self.set_auth_domain(d.getPrefixedString())
         continue
+
+
       if (tt == 0): raise ProtocolBuffer.ProtocolBufferDecodeError
       d.skipData(tt)
 
@@ -438,6 +507,7 @@ class CreateLogoutURLRequest(ProtocolBuffer.ProtocolMessage):
     2: ProtocolBuffer.Encoder.STRING,
   }, 2, ProtocolBuffer.Encoder.MAX_TYPE)
 
+
   _STYLE = """"""
   _STYLE_CONTENT_TYPE = """"""
 class CreateLogoutURLResponse(ProtocolBuffer.ProtocolMessage):
@@ -484,6 +554,13 @@ class CreateLogoutURLResponse(ProtocolBuffer.ProtocolMessage):
     n += self.lengthString(len(self.logout_url_))
     return n + 1
 
+  def ByteSizePartial(self):
+    n = 0
+    if (self.has_logout_url_):
+      n += 1
+      n += self.lengthString(len(self.logout_url_))
+    return n
+
   def Clear(self):
     self.clear_logout_url()
 
@@ -491,12 +568,19 @@ class CreateLogoutURLResponse(ProtocolBuffer.ProtocolMessage):
     out.putVarInt32(10)
     out.putPrefixedString(self.logout_url_)
 
+  def OutputPartial(self, out):
+    if (self.has_logout_url_):
+      out.putVarInt32(10)
+      out.putPrefixedString(self.logout_url_)
+
   def TryMerge(self, d):
     while d.avail() > 0:
       tt = d.getVarInt32()
       if tt == 10:
         self.set_logout_url(d.getPrefixedString())
         continue
+
+
       if (tt == 0): raise ProtocolBuffer.ProtocolBufferDecodeError
       d.skipData(tt)
 
@@ -522,20 +606,38 @@ class CreateLogoutURLResponse(ProtocolBuffer.ProtocolMessage):
     1: ProtocolBuffer.Encoder.STRING,
   }, 1, ProtocolBuffer.Encoder.MAX_TYPE)
 
+
   _STYLE = """"""
   _STYLE_CONTENT_TYPE = """"""
 class GetOAuthUserRequest(ProtocolBuffer.ProtocolMessage):
+  has_scope_ = 0
+  scope_ = ""
 
   def __init__(self, contents=None):
-    pass
     if contents is not None: self.MergeFromString(contents)
 
+  def scope(self): return self.scope_
+
+  def set_scope(self, x):
+    self.has_scope_ = 1
+    self.scope_ = x
+
+  def clear_scope(self):
+    if self.has_scope_:
+      self.has_scope_ = 0
+      self.scope_ = ""
+
+  def has_scope(self): return self.has_scope_
+
 
   def MergeFrom(self, x):
     assert x is not self
+    if (x.has_scope()): self.set_scope(x.scope())
 
   def Equals(self, x):
     if x is self: return 1
+    if self.has_scope_ != x.has_scope_: return 0
+    if self.has_scope_ and self.scope_ != x.scope_: return 0
     return 1
 
   def IsInitialized(self, debug_strs=None):
@@ -544,37 +646,60 @@ class GetOAuthUserRequest(ProtocolBuffer.ProtocolMessage):
 
   def ByteSize(self):
     n = 0
-    return n + 0
+    if (self.has_scope_): n += 1 + self.lengthString(len(self.scope_))
+    return n
+
+  def ByteSizePartial(self):
+    n = 0
+    if (self.has_scope_): n += 1 + self.lengthString(len(self.scope_))
+    return n
 
   def Clear(self):
-    pass
+    self.clear_scope()
 
   def OutputUnchecked(self, out):
-    pass
+    if (self.has_scope_):
+      out.putVarInt32(10)
+      out.putPrefixedString(self.scope_)
+
+  def OutputPartial(self, out):
+    if (self.has_scope_):
+      out.putVarInt32(10)
+      out.putPrefixedString(self.scope_)
 
   def TryMerge(self, d):
     while d.avail() > 0:
       tt = d.getVarInt32()
+      if tt == 10:
+        self.set_scope(d.getPrefixedString())
+        continue
+
+
       if (tt == 0): raise ProtocolBuffer.ProtocolBufferDecodeError
       d.skipData(tt)
 
 
   def __str__(self, prefix="", printElemNumber=0):
     res=""
+    if self.has_scope_: res+=prefix+("scope: %s\n" % self.DebugFormatString(self.scope_))
     return res
 
 
   def _BuildTagLookupTable(sparse, maxtag, default=None):
     return tuple([sparse.get(i, default) for i in xrange(0, 1+maxtag)])
 
+  kscope = 1
 
   _TEXT = _BuildTagLookupTable({
     0: "ErrorCode",
-  }, 0)
+    1: "scope",
+  }, 1)
 
   _TYPES = _BuildTagLookupTable({
     0: ProtocolBuffer.Encoder.NUMERIC,
-  }, 0, ProtocolBuffer.Encoder.MAX_TYPE)
+    1: ProtocolBuffer.Encoder.STRING,
+  }, 1, ProtocolBuffer.Encoder.MAX_TYPE)
+
 
   _STYLE = """"""
   _STYLE_CONTENT_TYPE = """"""
@@ -706,6 +831,21 @@ class GetOAuthUserResponse(ProtocolBuffer.ProtocolMessage):
     if (self.has_is_admin_): n += 2
     return n + 3
 
+  def ByteSizePartial(self):
+    n = 0
+    if (self.has_email_):
+      n += 1
+      n += self.lengthString(len(self.email_))
+    if (self.has_user_id_):
+      n += 1
+      n += self.lengthString(len(self.user_id_))
+    if (self.has_auth_domain_):
+      n += 1
+      n += self.lengthString(len(self.auth_domain_))
+    if (self.has_user_organization_): n += 1 + self.lengthString(len(self.user_organization_))
+    if (self.has_is_admin_): n += 2
+    return n
+
   def Clear(self):
     self.clear_email()
     self.clear_user_id()
@@ -727,6 +867,23 @@ class GetOAuthUserResponse(ProtocolBuffer.ProtocolMessage):
       out.putVarInt32(40)
       out.putBoolean(self.is_admin_)
 
+  def OutputPartial(self, out):
+    if (self.has_email_):
+      out.putVarInt32(10)
+      out.putPrefixedString(self.email_)
+    if (self.has_user_id_):
+      out.putVarInt32(18)
+      out.putPrefixedString(self.user_id_)
+    if (self.has_auth_domain_):
+      out.putVarInt32(26)
+      out.putPrefixedString(self.auth_domain_)
+    if (self.has_user_organization_):
+      out.putVarInt32(34)
+      out.putPrefixedString(self.user_organization_)
+    if (self.has_is_admin_):
+      out.putVarInt32(40)
+      out.putBoolean(self.is_admin_)
+
   def TryMerge(self, d):
     while d.avail() > 0:
       tt = d.getVarInt32()
@@ -745,6 +902,8 @@ class GetOAuthUserResponse(ProtocolBuffer.ProtocolMessage):
       if tt == 40:
         self.set_is_admin(d.getBoolean())
         continue
+
+
       if (tt == 0): raise ProtocolBuffer.ProtocolBufferDecodeError
       d.skipData(tt)
 
@@ -786,6 +945,7 @@ class GetOAuthUserResponse(ProtocolBuffer.ProtocolMessage):
     5: ProtocolBuffer.Encoder.NUMERIC,
   }, 5, ProtocolBuffer.Encoder.MAX_TYPE)
 
+
   _STYLE = """"""
   _STYLE_CONTENT_TYPE = """"""
 class CheckOAuthSignatureRequest(ProtocolBuffer.ProtocolMessage):
@@ -808,7 +968,11 @@ class CheckOAuthSignatureRequest(ProtocolBuffer.ProtocolMessage):
 
   def ByteSize(self):
     n = 0
-    return n + 0
+    return n
+
+  def ByteSizePartial(self):
+    n = 0
+    return n
 
   def Clear(self):
     pass
@@ -816,9 +980,14 @@ class CheckOAuthSignatureRequest(ProtocolBuffer.ProtocolMessage):
   def OutputUnchecked(self, out):
     pass
 
+  def OutputPartial(self, out):
+    pass
+
   def TryMerge(self, d):
     while d.avail() > 0:
       tt = d.getVarInt32()
+
+
       if (tt == 0): raise ProtocolBuffer.ProtocolBufferDecodeError
       d.skipData(tt)
 
@@ -840,6 +1009,7 @@ class CheckOAuthSignatureRequest(ProtocolBuffer.ProtocolMessage):
     0: ProtocolBuffer.Encoder.NUMERIC,
   }, 0, ProtocolBuffer.Encoder.MAX_TYPE)
 
+
   _STYLE = """"""
   _STYLE_CONTENT_TYPE = """"""
 class CheckOAuthSignatureResponse(ProtocolBuffer.ProtocolMessage):
@@ -886,6 +1056,13 @@ class CheckOAuthSignatureResponse(ProtocolBuffer.ProtocolMessage):
     n += self.lengthString(len(self.oauth_consumer_key_))
     return n + 1
 
+  def ByteSizePartial(self):
+    n = 0
+    if (self.has_oauth_consumer_key_):
+      n += 1
+      n += self.lengthString(len(self.oauth_consumer_key_))
+    return n
+
   def Clear(self):
     self.clear_oauth_consumer_key()
 
@@ -893,12 +1070,19 @@ class CheckOAuthSignatureResponse(ProtocolBuffer.ProtocolMessage):
     out.putVarInt32(10)
     out.putPrefixedString(self.oauth_consumer_key_)
 
+  def OutputPartial(self, out):
+    if (self.has_oauth_consumer_key_):
+      out.putVarInt32(10)
+      out.putPrefixedString(self.oauth_consumer_key_)
+
   def TryMerge(self, d):
     while d.avail() > 0:
       tt = d.getVarInt32()
       if tt == 10:
         self.set_oauth_consumer_key(d.getPrefixedString())
         continue
+
+
       if (tt == 0): raise ProtocolBuffer.ProtocolBufferDecodeError
       d.skipData(tt)
 
@@ -924,6 +1108,7 @@ class CheckOAuthSignatureResponse(ProtocolBuffer.ProtocolMessage):
     1: ProtocolBuffer.Encoder.STRING,
   }, 1, ProtocolBuffer.Encoder.MAX_TYPE)
 
+
   _STYLE = """"""
   _STYLE_CONTENT_TYPE = """"""
 class CreateFederatedLoginRequest(ProtocolBuffer.ProtocolMessage):
@@ -1012,6 +1197,17 @@ class CreateFederatedLoginRequest(ProtocolBuffer.ProtocolMessage):
     if (self.has_authority_): n += 1 + self.lengthString(len(self.authority_))
     return n + 2
 
+  def ByteSizePartial(self):
+    n = 0
+    if (self.has_claimed_id_):
+      n += 1
+      n += self.lengthString(len(self.claimed_id_))
+    if (self.has_continue_url_):
+      n += 1
+      n += self.lengthString(len(self.continue_url_))
+    if (self.has_authority_): n += 1 + self.lengthString(len(self.authority_))
+    return n
+
   def Clear(self):
     self.clear_claimed_id()
     self.clear_continue_url()
@@ -1026,6 +1222,17 @@ class CreateFederatedLoginRequest(ProtocolBuffer.ProtocolMessage):
       out.putVarInt32(26)
       out.putPrefixedString(self.authority_)
 
+  def OutputPartial(self, out):
+    if (self.has_claimed_id_):
+      out.putVarInt32(10)
+      out.putPrefixedString(self.claimed_id_)
+    if (self.has_continue_url_):
+      out.putVarInt32(18)
+      out.putPrefixedString(self.continue_url_)
+    if (self.has_authority_):
+      out.putVarInt32(26)
+      out.putPrefixedString(self.authority_)
+
   def TryMerge(self, d):
     while d.avail() > 0:
       tt = d.getVarInt32()
@@ -1038,6 +1245,8 @@ class CreateFederatedLoginRequest(ProtocolBuffer.ProtocolMessage):
       if tt == 26:
         self.set_authority(d.getPrefixedString())
         continue
+
+
       if (tt == 0): raise ProtocolBuffer.ProtocolBufferDecodeError
       d.skipData(tt)
 
@@ -1071,6 +1280,7 @@ class CreateFederatedLoginRequest(ProtocolBuffer.ProtocolMessage):
     3: ProtocolBuffer.Encoder.STRING,
   }, 3, ProtocolBuffer.Encoder.MAX_TYPE)
 
+
   _STYLE = """"""
   _STYLE_CONTENT_TYPE = """"""
 class CreateFederatedLoginResponse(ProtocolBuffer.ProtocolMessage):
@@ -1117,6 +1327,13 @@ class CreateFederatedLoginResponse(ProtocolBuffer.ProtocolMessage):
     n += self.lengthString(len(self.redirected_url_))
     return n + 1
 
+  def ByteSizePartial(self):
+    n = 0
+    if (self.has_redirected_url_):
+      n += 1
+      n += self.lengthString(len(self.redirected_url_))
+    return n
+
   def Clear(self):
     self.clear_redirected_url()
 
@@ -1124,12 +1341,19 @@ class CreateFederatedLoginResponse(ProtocolBuffer.ProtocolMessage):
     out.putVarInt32(10)
     out.putPrefixedString(self.redirected_url_)
 
+  def OutputPartial(self, out):
+    if (self.has_redirected_url_):
+      out.putVarInt32(10)
+      out.putPrefixedString(self.redirected_url_)
+
   def TryMerge(self, d):
     while d.avail() > 0:
       tt = d.getVarInt32()
       if tt == 10:
         self.set_redirected_url(d.getPrefixedString())
         continue
+
+
       if (tt == 0): raise ProtocolBuffer.ProtocolBufferDecodeError
       d.skipData(tt)
 
@@ -1155,6 +1379,7 @@ class CreateFederatedLoginResponse(ProtocolBuffer.ProtocolMessage):
     1: ProtocolBuffer.Encoder.STRING,
   }, 1, ProtocolBuffer.Encoder.MAX_TYPE)
 
+
   _STYLE = """"""
   _STYLE_CONTENT_TYPE = """"""
 class CreateFederatedLogoutRequest(ProtocolBuffer.ProtocolMessage):
@@ -1201,6 +1426,13 @@ class CreateFederatedLogoutRequest(ProtocolBuffer.ProtocolMessage):
     n += self.lengthString(len(self.destination_url_))
     return n + 1
 
+  def ByteSizePartial(self):
+    n = 0
+    if (self.has_destination_url_):
+      n += 1
+      n += self.lengthString(len(self.destination_url_))
+    return n
+
   def Clear(self):
     self.clear_destination_url()
 
@@ -1208,12 +1440,19 @@ class CreateFederatedLogoutRequest(ProtocolBuffer.ProtocolMessage):
     out.putVarInt32(10)
     out.putPrefixedString(self.destination_url_)
 
+  def OutputPartial(self, out):
+    if (self.has_destination_url_):
+      out.putVarInt32(10)
+      out.putPrefixedString(self.destination_url_)
+
   def TryMerge(self, d):
     while d.avail() > 0:
       tt = d.getVarInt32()
       if tt == 10:
         self.set_destination_url(d.getPrefixedString())
         continue
+
+
       if (tt == 0): raise ProtocolBuffer.ProtocolBufferDecodeError
       d.skipData(tt)
 
@@ -1239,6 +1478,7 @@ class CreateFederatedLogoutRequest(ProtocolBuffer.ProtocolMessage):
     1: ProtocolBuffer.Encoder.STRING,
   }, 1, ProtocolBuffer.Encoder.MAX_TYPE)
 
+
   _STYLE = """"""
   _STYLE_CONTENT_TYPE = """"""
 class CreateFederatedLogoutResponse(ProtocolBuffer.ProtocolMessage):
@@ -1285,6 +1525,13 @@ class CreateFederatedLogoutResponse(ProtocolBuffer.ProtocolMessage):
     n += self.lengthString(len(self.logout_url_))
     return n + 1
 
+  def ByteSizePartial(self):
+    n = 0
+    if (self.has_logout_url_):
+      n += 1
+      n += self.lengthString(len(self.logout_url_))
+    return n
+
   def Clear(self):
     self.clear_logout_url()
 
@@ -1292,12 +1539,19 @@ class CreateFederatedLogoutResponse(ProtocolBuffer.ProtocolMessage):
     out.putVarInt32(10)
     out.putPrefixedString(self.logout_url_)
 
+  def OutputPartial(self, out):
+    if (self.has_logout_url_):
+      out.putVarInt32(10)
+      out.putPrefixedString(self.logout_url_)
+
   def TryMerge(self, d):
     while d.avail() > 0:
       tt = d.getVarInt32()
       if tt == 10:
         self.set_logout_url(d.getPrefixedString())
         continue
+
+
       if (tt == 0): raise ProtocolBuffer.ProtocolBufferDecodeError
       d.skipData(tt)
 
@@ -1323,6 +1577,7 @@ class CreateFederatedLogoutResponse(ProtocolBuffer.ProtocolMessage):
     1: ProtocolBuffer.Encoder.STRING,
   }, 1, ProtocolBuffer.Encoder.MAX_TYPE)
 
+
   _STYLE = """"""
   _STYLE_CONTENT_TYPE = """"""
 
