@@ -15,12 +15,19 @@
 # limitations under the License.
 #
 
+
+
+
 """Simple datastore view and interactive console, for use in dev_appserver."""
 
 
 
 
 
+
+
+
+
 import cgi
 import csv
 import cStringIO
@@ -41,6 +48,8 @@ import urllib
 import urlparse
 import wsgiref.handlers
 
+
+
 try:
   from google.appengine.cron import groctimespecification
   from google.appengine.api import croninfo
@@ -55,12 +64,13 @@ from google.appengine.api import datastore_admin
 from google.appengine.api import datastore_types
 from google.appengine.api import datastore_errors
 from google.appengine.api import memcache
-from google.appengine.api.labs import taskqueue
+from google.appengine.api import taskqueue
 from google.appengine.api import users
 from google.appengine.ext import db
 from google.appengine.ext import webapp
 from google.appengine.ext.webapp import template
 
+
 _DEBUG = True
 
 
@@ -206,11 +216,13 @@ class InteractiveExecuteHandler(BaseRequestHandler):
   PATH = InteractivePageHandler.PATH + '/execute'
 
   def post(self):
+
     save_stdout = sys.stdout
     results_io = cStringIO.StringIO()
     try:
       sys.stdout = results_io
 
+
       code = self.request.get('code')
       code = code.replace("\r\n", "\n")
 
@@ -250,7 +262,10 @@ class CronPageHandler(BaseRequestHandler):
           job['timezone'] = entry.timezone
         job['url'] = entry.url
         job['schedule'] = entry.schedule
+
+
         schedule = groctimespecification.GrocTimeSpecification(entry.schedule)
+
         matches = schedule.GetMatches(now, 3)
         job['times'] = []
         for match in matches:
@@ -265,6 +280,7 @@ class XMPPPageHandler(BaseRequestHandler):
 
   def get(self):
     """Shows template displaying the XMPP."""
+
     xmpp_configured = True
     values = {
       'xmpp_configured': xmpp_configured,
@@ -279,6 +295,7 @@ class InboundMailPageHandler(BaseRequestHandler):
 
   def get(self):
     """Shows template displaying the Inbound Mail form."""
+
     inboundmail_configured = True
     values = {
       'inboundmail_configured': inboundmail_configured,
@@ -306,6 +323,8 @@ class QueuesPageHandler(BaseRequestHandler):
     """Handle modifying actions and/or redirect to GET page."""
 
     if self.request.get('action:purgequeue'):
+
+
       self.stub.FlushQueue(self.request.get('queue'))
     self.redirect(self.request.path_url)
 
@@ -365,6 +384,8 @@ class MemcachePageHandler(BaseRequestHandler):
   """Shows stats about memcache and query form to get values."""
   PATH = '/memcache'
 
+
+
   TYPES = ((str, str, 'String'),
            (unicode, unicode, 'Unicode String'),
            (bool, lambda value: MemcachePageHandler._ToBool(value), 'Boolean'),
@@ -406,16 +427,21 @@ class MemcachePageHandler(BaseRequestHandler):
       value = memcache.get(key)
     except (pickle.UnpicklingError, AttributeError, EOFError, ImportError,
             IndexError), e:
+
+
       msg = 'Failed to retrieve value from cache: %s' % e
       return msg, 'error'
 
     if value is None:
+
       return None, self.DEFAULT_TYPESTR_FOR_NEW
 
+
     for typeobj, _, typestr in self.TYPES:
       if isinstance(value, typeobj):
         break
     else:
+
       typestr = 'pickled'
       value = pprint.pformat(value, indent=2)
 
@@ -451,16 +477,19 @@ class MemcachePageHandler(BaseRequestHandler):
     edit = self.request.get('edit')
     key = self.request.get('key')
     if edit:
+
       key = edit
       values['show_stats'] = False
       values['show_value'] = False
       values['show_valueform'] = True
       values['types'] = [typestr for _, _, typestr in self.TYPES]
     elif key:
+
       values['show_stats'] = True
       values['show_value'] = True
       values['show_valueform'] = False
     else:
+
       values['show_stats'] = True
       values['show_valueform'] = False
       values['show_value'] = False
@@ -478,6 +507,7 @@ class MemcachePageHandler(BaseRequestHandler):
     if values['show_stats']:
       memcache_stats = memcache.get_stats()
       if not memcache_stats:
+
         memcache_stats = {'hits': 0, 'misses': 0, 'byte_hits': 0, 'items': 0,
                           'bytes': 0, 'oldest_item_age': 0}
       values['stats'] = memcache_stats
@@ -594,6 +624,7 @@ class DatastoreRequestHandler(BaseRequestHandler):
       return ([], 0)
     query = datastore.Query(kind, _namespace=namespace)
 
+
     order = self.request.get('order')
     order_type = self.request.get('order_type')
     if order and order_type:
@@ -606,6 +637,7 @@ class DatastoreRequestHandler(BaseRequestHandler):
       try:
         query.Order((order, order_type, direction))
       except datastore_errors.BadArgumentError:
+
         pass
 
     if not start:
@@ -668,11 +700,16 @@ class DatastoreQueryHandler(DatastoreRequestHandler):
     The only complex part of that process is calculating the pager variables
     to generate the Gooooogle pager at the bottom of the page.
     """
+
+
+
     result_set, total = self.execute_query()
     key_values = self.get_key_values(result_set)
     keys = key_values.keys()
     keys.sort()
 
+
+
     headers = []
     for key in keys:
       sample_value = key_values[key][0]
@@ -681,6 +718,8 @@ class DatastoreQueryHandler(DatastoreRequestHandler):
         'type': DataType.get(sample_value).name(),
       })
 
+
+
     entities = []
     edit_path = self.base_path() + DatastoreEditHandler.PATH
     for entity in result_set:
@@ -711,6 +750,7 @@ class DatastoreQueryHandler(DatastoreRequestHandler):
         'edit_uri': edit_path + '?key=' + str(entity.key()) + '&kind=' + urllib.quote(self.request.get('kind')) + '&next=' + urllib.quote(self.request.uri),
       })
 
+
     start = self.start()
     num = self.num()
     max_pager_links = 8
@@ -733,6 +773,7 @@ class DatastoreQueryHandler(DatastoreRequestHandler):
     else:
       kinds = self.get_kinds(self.request.get('namespace'))
 
+
     values = {
         'request': self.request,
         'in_production': in_production,
@@ -774,6 +815,8 @@ class DatastoreBatchEditHandler(DatastoreRequestHandler):
   def post(self):
     kind = self.request.get('kind')
 
+
+
     keys = []
     index = 0
     num_keys = int(self.request.get('numkeys'))
@@ -784,6 +827,7 @@ class DatastoreBatchEditHandler(DatastoreRequestHandler):
 
     if self.request.get('action') == 'Delete':
       num_deleted = 0
+
       for key in keys:
         datastore.Delete(datastore.Key(key))
         num_deleted = num_deleted + 1
@@ -793,6 +837,7 @@ class DatastoreBatchEditHandler(DatastoreRequestHandler):
         '%s&msg=%s' % (self.request.get('next'), urllib.quote_plus(message)))
       return
 
+
     self.error(404)
 
 
@@ -808,6 +853,7 @@ class DatastoreEditHandler(DatastoreRequestHandler):
   PATH = DatastoreQueryHandler.PATH + '/edit'
 
   def get(self):
+
     entity_key = self.request.get('key')
     if entity_key:
       key_instance = datastore.Key(entity_key)
@@ -819,10 +865,15 @@ class DatastoreEditHandler(DatastoreRequestHandler):
       entity = datastore.Get(key_instance)
       sample_entities = [entity]
     else:
+
       kind = self.request.get('kind')
       sample_entities = self.execute_query()[0]
 
     if len(sample_entities) < 1:
+
+
+
+
       next_uri = self.request.get('next')
       next_uri += '&msg=%s' % urllib.quote_plus(
           "The kind %s doesn't exist in the %s namespace" % (
@@ -853,6 +904,9 @@ class DatastoreEditHandler(DatastoreRequestHandler):
       parent_kind = None
       parent_key_string = None
 
+
+
+
     fields = []
     key_values = self.get_key_values(sample_entities)
     for key, sample_values in key_values.iteritems():
@@ -868,6 +922,10 @@ class DatastoreEditHandler(DatastoreRequestHandler):
       field = data_type.input_field(name, value, sample_values)
       fields.append((key, data_type.name(), field))
 
+
+
+
+
     self.generate('datastore_edit.html', {
       'kind': kind,
       'key': entity_key,
@@ -883,9 +941,11 @@ class DatastoreEditHandler(DatastoreRequestHandler):
     })
 
   def post(self):
+
     kind = self.request.get('kind')
     entity_key = self.request.get('key')
     if entity_key:
+
       if self.request.get('action') == 'Delete':
         datastore.Delete(datastore.Key(entity_key))
         self.redirect(self.request.get('next'))
@@ -905,22 +965,28 @@ class DatastoreEditHandler(DatastoreRequestHandler):
         field_name = arg[bar + 1:]
         form_value = self.request.get(arg)
         data_type = DataType.get_by_name(data_type_name)
+
+
+
         if entity and entity.has_key(field_name):
           old_formatted_value = data_type.format(entity[field_name])
           if old_formatted_value == ustr(form_value):
             continue
 
+
         if len(form_value) > 0:
           value = data_type.parse(form_value)
           entity[field_name] = value
         elif entity.has_key(field_name):
           del entity[field_name]
 
+
     datastore.Put(entity)
 
     self.redirect(self.request.get('next'))
 
 
+
 class DataType(object):
   """A DataType represents a data type in the datastore.
 
@@ -963,6 +1029,7 @@ class DataType(object):
     return 30
 
   def additional_short_value_html(self, unused_value):
+
     return ''
 
 
@@ -1096,6 +1163,7 @@ class BoolType(DataType):
       return True
     if value.lower() is 'false':
       return False
+
     return bool(int(value))
 
   def python_type(self):
@@ -1154,6 +1222,7 @@ class UserType(DataType):
     return 15
 
 
+
 class ReferenceType(DataType):
   def name(self):
     return 'Key'
@@ -1302,6 +1371,8 @@ class BlobKeyType(StringType):
     return datastore_types.BlobKey
 
 
+
+
 _DATA_TYPES = {
   types.NoneType: NoneType(),
   types.StringType: StringType(),
@@ -1354,6 +1425,7 @@ def _ParseCronYaml():
   return None
 
 
+
 def PseudoBreadcrumbs(key):
   """Return a string that looks like the breadcrumbs (for key properties).
 
@@ -1400,6 +1472,8 @@ def main():
   wsgiref.handlers.CGIHandler().run(application)
 
 
+
+
 import django
 if django.VERSION[:2] < (0, 97):
   from django.template import defaultfilters
