@@ -15,6 +15,9 @@
 # limitations under the License.
 #
 
+
+
+
 """A Python blobstore API used by app developers.
 
 Contains methods used to interface with Blobstore API.  Includes db.Model-like
@@ -24,6 +27,10 @@ class representing a blob-key.
 
 
 
+
+
+
+
 import cgi
 import email
 import os
@@ -77,6 +84,8 @@ BLOB_RANGE_HEADER = blobstore.BLOB_RANGE_HEADER
 MAX_BLOB_FETCH_SIZE = blobstore.MAX_BLOB_FETCH_SIZE
 UPLOAD_INFO_CREATION_HEADER = blobstore.UPLOAD_INFO_CREATION_HEADER
 
+
+
 class _GqlQuery(db.GqlQuery):
   """GqlQuery class that explicitly sets model-class.
 
@@ -88,6 +97,7 @@ class _GqlQuery(db.GqlQuery):
   mechanism but will be removed in the future.  DO NOT USE.
   """
 
+
   def __init__(self, query_string, model_class, *args, **kwds):
     """Constructor.
 
@@ -97,13 +107,18 @@ class _GqlQuery(db.GqlQuery):
       *args: Positional arguments used to bind numeric references in the query.
       **kwds: Dictionary-based arguments for named references.
     """
+
+
     from google.appengine.ext import gql
     app = kwds.pop('_app', None)
     self._proto_query = gql.GQL(query_string, _app=app, namespace='')
+
     super(db.GqlQuery, self).__init__(model_class, namespace='')
     self.bind(*args, **kwds)
 
 
+
+
 class BlobInfo(object):
   """Information about blobs in Blobstore.
 
@@ -130,6 +145,9 @@ class BlobInfo(object):
 
   _unindexed_properties = frozenset()
 
+
+  _all_properties = frozenset(['content_type', 'creation', 'filename', 'size'])
+
   @property
   def content_type(self):
     return self.__get_value('content_type')
@@ -146,6 +164,10 @@ class BlobInfo(object):
   def size(self):
     return self.__get_value('size')
 
+  @property
+  def md5_hash(self):
+    return self.__get_value('md5_hash')
+
   def __init__(self, entity_or_blob_key, _values=None):
     """Constructor for wrapping blobstore entity.
 
@@ -163,6 +185,8 @@ class BlobInfo(object):
     else:
       TypeError('Must provide Entity or BlobKey')
 
+
+
   @classmethod
   def from_entity(cls, entity):
     """Convert entity to BlobInfo.
@@ -172,6 +196,8 @@ class BlobInfo(object):
     """
     return BlobInfo(entity)
 
+
+
   @classmethod
   def properties(cls):
     """Set of properties that belong to BlobInfo.
@@ -179,7 +205,7 @@ class BlobInfo(object):
     This method is required for compatibility with the current db.py query
     mechanism but will be removed in the future.  DO NOT USE.
     """
-    return set(('content_type', 'creation', 'filename', 'size'))
+    return set(cls._all_properties)
 
   def __get_value(self, name):
     """Get a BlobInfo value, loading entity if necessary.
@@ -291,6 +317,7 @@ class BlobInfo(object):
                      *args,
                      **kwds)
 
+
   @classmethod
   def kind(self):
     """Get the entity kind for the BlobInfo.
@@ -315,6 +342,7 @@ class BlobInfo(object):
     """
     if isinstance(keys, (list, tuple)):
       multiple = True
+
       keys = list(keys)
     else:
       multiple = False
@@ -553,6 +581,7 @@ class BlobReader(object):
         data: The bytes read from the buffer.
         size: The remaining unread byte count.
     """
+
     if not self.__blob_key:
       raise ValueError("File is closed")
 
@@ -562,11 +591,13 @@ class BlobReader(object):
       end_pos = self.__buffer_position + size
     data = self.__buffer[self.__buffer_position:end_pos]
 
+
     data_length = len(data)
     size -= data_length
     self.__position += data_length
     self.__buffer_position += data_length
 
+
     if self.__buffer_position == len(self.__buffer):
       self.__buffer = ""
       self.__buffer_position = 0
@@ -581,6 +612,7 @@ class BlobReader(object):
         [self.__buffer_size, MAX_BLOB_FETCH_SIZE].
     """
     read_size = min(max(size, self.__buffer_size), MAX_BLOB_FETCH_SIZE)
+
     self.__buffer = fetch_data(self.__blob_key, self.__position,
                                self.__position + read_size - 1)
     self.__buffer_position = 0
@@ -635,11 +667,13 @@ class BlobReader(object):
         end_pos = self.__buffer_position + size
       newline_pos = self.__buffer.find('\n', self.__buffer_position, end_pos)
       if newline_pos != -1:
+
         data_list.append(
             self.__read_from_buffer(newline_pos
                                     - self.__buffer_position + 1)[0])
         break
       else:
+
         data, size = self.__read_from_buffer(size)
         data_list.append(data)
         if size == 0 or self.__eof:
@@ -666,6 +700,7 @@ class BlobReader(object):
       if sizehint:
         sizehint -= len(line)
       if not line:
+
         break
       lines.append(line)
     return lines
