@@ -15,10 +15,28 @@
 # limitations under the License.
 #
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 """Defines executor tasks handlers for MapReduce implementation."""
 
 
 
+
+
 import datetime
 import logging
 import math
@@ -32,14 +50,19 @@ from google.appengine.ext import db
 from google.appengine.ext.mapreduce import base_handler
 from google.appengine.ext.mapreduce import context
 from google.appengine.ext.mapreduce import model
+from google.appengine.ext.mapreduce import operation
 from google.appengine.ext.mapreduce import quota
 from google.appengine.ext.mapreduce import util
 
 
+
 _QUOTA_BATCH_SIZE = 20
 
+
+
 _SLICE_DURATION_SEC = 15
 
+
 _CONTROLLER_PERIOD_SEC = 2
 
 
@@ -72,6 +95,7 @@ def _run_task_hook(hooks, method, task, queue_name):
     try:
       getattr(hooks, method)(task, queue_name)
     except NotImplementedError:
+
       return False
 
     return True
@@ -98,19 +122,18 @@ class MapperWorkerCallbackHandler(base_handler.TaskQueueHandler):
 
   def handle(self):
     """Handle request."""
-    spec = model.MapreduceSpec.from_json_str(
-        self.request.get("mapreduce_spec"))
+    tstate = model.TransientShardState.from_request(self.request)
+    spec = tstate.mapreduce_spec
     self._start_time = self._time()
-    shard_id = self.shard_id()
-
-    logging.debug("post: shard=%s slice=%s headers=%s",
-                  shard_id, self.slice_id(), self.request.headers)
+    shard_id = tstate.shard_id
 
     shard_state, control = db.get([
         model.ShardState.get_key_by_shard_id(shard_id),
         model.MapreduceControl.get_key_by_job_id(spec.mapreduce_id),
     ])
     if not shard_state:
+
+
       logging.error("State not found for shard ID %r; shutting down",
                     shard_id)
       return
@@ -118,13 +141,15 @@ class MapperWorkerCallbackHandler(base_handler.TaskQueueHandler):
     if control and control.command == model.MapreduceControl.ABORT:
       logging.info("Abort command received by shard %d of job '%s'",
                    shard_state.shard_number, shard_state.mapreduce_id)
+      if tstate.output_writer:
+        tstate.output_writer.finalize(None, shard_state.shard_number)
       shard_state.active = False
       shard_state.result_status = model.ShardState.RESULT_ABORTED
-      shard_state.put()
+      shard_state.put(config=util.create_datastore_write_config(spec))
       model.MapreduceControl.abort(spec.mapreduce_id)
       return
 
-    input_reader = self.input_reader(spec.mapper)
+    input_reader = tstate.input_reader
 
     if spec.mapper.params.get("enable_quota", True):
       quota_consumer = quota.QuotaConsumer(
@@ -139,10 +164,14 @@ class MapperWorkerCallbackHandler(base_handler.TaskQueueHandler):
     context.Context._set(ctx)
 
     try:
+
+
       if not quota_consumer or quota_consumer.check():
         scan_aborted = False
         entity = None
 
+
+
         if not quota_consumer or quota_consumer.consume():
           for entity in input_reader:
             if isinstance(entity, db.Model):
@@ -150,7 +179,8 @@ class MapperWorkerCallbackHandler(base_handler.TaskQueueHandler):
             else:
               shard_state.last_work_item = repr(entity)[:100]
 
-            scan_aborted = not self.process_entity(entity, ctx)
+            scan_aborted = not self.process_entity(entity, ctx, tstate)
+
 
             if (quota_consumer and not scan_aborted and
                 not quota_consumer.consume()):
@@ -164,21 +194,32 @@ class MapperWorkerCallbackHandler(base_handler.TaskQueueHandler):
         if not scan_aborted:
           logging.info("Processing done for shard %d of job '%s'",
                        shard_state.shard_number, shard_state.mapreduce_id)
+
+
           if quota_consumer:
             quota_consumer.put(1)
           shard_state.active = False
           shard_state.result_status = model.ShardState.RESULT_SUCCESS
 
+      if not shard_state.active:
+
+        if tstate.output_writer:
+          tstate.output_writer.finalize(ctx, shard_state.shard_number)
+
+
+
       ctx.flush()
     finally:
       context.Context._set(None)
       if quota_consumer:
         quota_consumer.dispose()
 
-    if shard_state.active:
-      self.reschedule(spec, input_reader)
 
-  def process_entity(self, entity, ctx):
+
+    if shard_state.active:
+      self.reschedule(tstate)
+
+  def process_entity(self, entity, ctx, transient_shard_state):
     """Process a single entity.
 
     Call mapper handler on the entity.
@@ -195,18 +236,15 @@ class MapperWorkerCallbackHandler(base_handler.TaskQueueHandler):
     handler = ctx.mapreduce_spec.mapper.handler
     if util.is_generator_function(handler):
       for result in handler(entity):
-        if callable(result):
+        if isinstance(result, operation.Operation):
           result(ctx)
         else:
-          try:
-            if len(result) == 2:
-              logging.error("Collectors not implemented yet")
-            else:
-              logging.error("Got bad output tuple of length %d", len(result))
-          except TypeError:
+          output_writer = transient_shard_state.output_writer
+          if not output_writer:
             logging.error(
-                "Handler yielded type %s, expected a callable or a tuple",
-                result.__class__.__name__)
+                "Handler yielded %s, but no output writer is set.", result)
+          else:
+            output_writer.write(result, ctx)
     else:
       handler(entity)
 
@@ -216,103 +254,41 @@ class MapperWorkerCallbackHandler(base_handler.TaskQueueHandler):
       return False
     return True
 
-  def shard_id(self):
-    """Get shard unique identifier of this task from request.
-
-    Returns:
-      shard identifier as string.
-    """
-    return str(self.request.get("shard_id"))
-
-  def slice_id(self):
-    """Get slice unique identifier of this task from request.
-
-    Returns:
-      slice identifier as int.
-    """
-    return int(self.request.get("slice_id"))
-
-  def input_reader(self, mapper_spec):
-    """Get the reader from mapper_spec initialized with the request's state.
-
-    Args:
-      mapper_spec: a mapper spec containing the immutable mapper state.
-
-    Returns:
-      An initialized InputReader.
-    """
-    input_reader_spec_dict = simplejson.loads(
-        self.request.get("input_reader_state"))
-    return mapper_spec.input_reader_class().from_json(
-        input_reader_spec_dict)
-
-  @staticmethod
-  def worker_parameters(mapreduce_spec,
-                        shard_id,
-                        slice_id,
-                        input_reader):
-    """Fill in mapper worker task parameters.
-
-    Returned parameters map is to be used as task payload, and it contains
-    all the data, required by mapper worker to perform its function.
-
-    Args:
-      mapreduce_spec: specification of the mapreduce.
-      shard_id: id of the shard (part of the whole dataset).
-      slice_id: id of the slice (part of the shard).
-      input_reader: InputReader containing the remaining inputs for this
-        shard.
-
-    Returns:
-      string->string map of parameters to be used as task payload.
-    """
-    return {"mapreduce_spec": mapreduce_spec.to_json_str(),
-            "shard_id": shard_id,
-            "slice_id": str(slice_id),
-            "input_reader_state": input_reader.to_json_str()}
-
   @staticmethod
   def get_task_name(shard_id, slice_id):
     """Compute single worker task name.
 
     Args:
-      shard_id: id of the shard (part of the whole dataset) as string.
-      slice_id: id of the slice (part of the shard) as int.
+      transient_shard_state: An instance of TransientShardState.
 
     Returns:
       task name which should be used to process specified shard/slice.
     """
-    return "appengine-mrshard-%s-%s" % (shard_id, slice_id)
 
-  def reschedule(self, mapreduce_spec, input_reader):
+
+    return "appengine-mrshard-%s-%s" % (
+        shard_id, slice_id)
+
+  def reschedule(self, transient_shard_state):
     """Reschedule worker task to continue scanning work.
 
     Args:
-      mapreduce_spec: mapreduce specification.
-      input_reader: remaining input reader to process.
+      transient_shard_state: an instance of TransientShardState.
     """
-    MapperWorkerCallbackHandler.schedule_slice(
-        self.base_path(), mapreduce_spec, self.shard_id(),
-        self.slice_id() + 1, input_reader)
+    transient_shard_state.slice_id += 1
+    MapperWorkerCallbackHandler._schedule_slice(
+        transient_shard_state)
 
   @classmethod
-  def schedule_slice(cls,
-                     base_path,
-                     mapreduce_spec,
-                     shard_id,
-                     slice_id,
-                     input_reader,
-                     queue_name=None,
-                     eta=None,
-                     countdown=None):
+  def _schedule_slice(cls,
+                      transient_shard_state,
+                      queue_name=None,
+                      eta=None,
+                      countdown=None):
     """Schedule slice scanning by adding it to the task queue.
 
     Args:
-      base_path: base_path of mapreduce request handlers as string.
-      mapreduce_spec: mapreduce specification as MapreduceSpec.
-      shard_id: current shard id as string.
-      slice_id: slice id as int.
-      input_reader: remaining InputReader for given shard.
+      transient_shard_state: An instance of TransientShardState.
       queue_name: Optional queue to run on; uses the current queue of
         execution or the default queue if unspecified.
       eta: Absolute time when the MR should execute. May not be specified
@@ -321,14 +297,17 @@ class MapperWorkerCallbackHandler(base_handler.TaskQueueHandler):
       countdown: Time in seconds into the future that this MR should execute.
         Defaults to zero.
     """
-    task_params = MapperWorkerCallbackHandler.worker_parameters(
-        mapreduce_spec, shard_id, slice_id, input_reader)
-    task_name = MapperWorkerCallbackHandler.get_task_name(shard_id, slice_id)
-    queue_name = os.environ.get("HTTP_X_APPENGINE_QUEUENAME",
-                                queue_name or "default")
+    base_path = transient_shard_state.base_path
+    mapreduce_spec = transient_shard_state.mapreduce_spec
+
+    task_name = MapperWorkerCallbackHandler.get_task_name(
+        transient_shard_state.shard_id,
+        transient_shard_state.slice_id)
+    queue_name = queue_name or os.environ.get("HTTP_X_APPENGINE_QUEUENAME",
+                                              "default")
 
     worker_task = taskqueue.Task(url=base_path + "/worker_callback",
-                                 params=task_params,
+                                 params=transient_shard_state.to_dict(),
                                  name=task_name,
                                  eta=eta,
                                  countdown=countdown)
@@ -342,7 +321,10 @@ class MapperWorkerCallbackHandler(base_handler.TaskQueueHandler):
       except (taskqueue.TombstonedTaskError,
               taskqueue.TaskAlreadyExistsError), e:
         logging.warning("Task %r with params %r already exists. %s: %s",
-                        task_name, task_params, e.__class__, e)
+                        task_name,
+                        transient_shard_state.to_dict(),
+                        e.__class__,
+                        e)
 
 
 class ControllerCallbackHandler(base_handler.TaskQueueHandler):
@@ -368,6 +350,7 @@ class ControllerCallbackHandler(base_handler.TaskQueueHandler):
     spec = model.MapreduceSpec.from_json_str(
         self.request.get("mapreduce_spec"))
 
+
     logging.debug("post: id=%s headers=%s",
                   spec.mapreduce_id, self.request.headers)
 
@@ -382,6 +365,7 @@ class ControllerCallbackHandler(base_handler.TaskQueueHandler):
 
     shard_states = model.ShardState.find_by_mapreduce_id(spec.mapreduce_id)
     if state.active and len(shard_states) != spec.mapper.shard_count:
+
       logging.error("Incorrect number of shard states: %d vs %d; "
                     "aborting job '%s'",
                     len(shard_states), spec.mapper.shard_count,
@@ -403,12 +387,14 @@ class ControllerCallbackHandler(base_handler.TaskQueueHandler):
 
     if (not state.active and control and
         control.command == model.MapreduceControl.ABORT):
+
       logging.info("Abort signal received for job '%s'", spec.mapreduce_id)
       state.result_status = model.MapreduceState.RESULT_ABORTED
 
     if not state.active:
       state.active_shards = 0
       if not state.result_status:
+
         if [s for s in shard_states
             if s.result_status != model.ShardState.RESULT_SUCCESS]:
           state.result_status = model.MapreduceState.RESULT_FAILED
@@ -417,13 +403,21 @@ class ControllerCallbackHandler(base_handler.TaskQueueHandler):
         logging.info("Final result for job '%s' is '%s'",
                      spec.mapreduce_id, state.result_status)
 
+
+
     self.aggregate_state(state, shard_states)
     poll_time = state.last_poll_time
     state.last_poll_time = datetime.datetime.utcfromtimestamp(self._time())
 
+    config = util.create_datastore_write_config(spec)
+
     if not state.active:
+
+
+      if spec.mapper.output_writer_class():
+        spec.mapper.output_writer_class().finalize_job(state)
       def put_state(state):
-        state.put()
+        state.put(config=config)
         done_callback = spec.params.get(
             model.MapreduceSpec.PARAM_DONE_CALLBACK)
         if done_callback:
@@ -442,7 +436,7 @@ class ControllerCallbackHandler(base_handler.TaskQueueHandler):
       db.run_in_transaction(put_state, state)
       return
     else:
-      state.put()
+      state.put(config=config)
 
     processing_rate = int(spec.mapper.params.get(
         "processing_rate") or model._DEFAULT_PROCESSING_RATE_PER_SEC)
@@ -491,6 +485,7 @@ class ControllerCallbackHandler(base_handler.TaskQueueHandler):
     if not quota_refill:
       return
 
+
     for shard_state in active_shard_states:
       quota_manager.put(shard_state.shard_id, quota_refill)
 
@@ -507,12 +502,13 @@ class ControllerCallbackHandler(base_handler.TaskQueueHandler):
     """Compute single controller task name.
 
     Args:
-      mapreduce_spec: specification of the mapreduce.
-      serial_id: id of the invocation as int.
+      transient_shard_state: an instance of TransientShardState.
 
     Returns:
       task name which should be used to process specified shard/slice.
     """
+
+
     return "appengine-mrcontrol-%s-%s" % (
         mapreduce_spec.mapreduce_id, serial_id)
 
@@ -580,25 +576,52 @@ class KickOffJobHandler(base_handler.TaskQueueHandler):
     """Handles kick off request."""
     spec = model.MapreduceSpec.from_json_str(
         self._get_required_param("mapreduce_spec"))
+    app_id = self.request.get("app", None)
     queue_name = os.environ.get("HTTP_X_APPENGINE_QUEUENAME", "default")
     mapper_input_reader_class = spec.mapper.input_reader_class()
-    state = model.MapreduceState.get_by_job_id(spec.mapreduce_id)
+
+
+
+    state = model.MapreduceState.create_new(spec.mapreduce_id)
+    state.mapreduce_spec = spec
+    state.active = True
+
+    state.char_url = ""
+    state.sparkline_url = ""
+    if app_id:
+      state.app_id = app_id
 
     input_readers = mapper_input_reader_class.split_input(spec.mapper)
     if not input_readers:
+
       logging.warning("Found no mapper input data to process.")
       state.active = False
       state.active_shards = 0
-      state.put()
+      state.put(config=util.create_datastore_write_config(spec))
       return
 
-    spec.shard_count = len(input_readers)
 
+    spec.mapper.shard_count = len(input_readers)
+    state.active_shards = len(input_readers)
     state.mapreduce_spec = spec
-    state.put()
+
+    output_writer_class = spec.mapper.output_writer_class()
+    if output_writer_class:
+      output_writer_class.init_job(state)
+
+    output_writers = []
+    if output_writer_class:
+      for shard_number in range(len(input_readers)):
+        writer = output_writer_class.create(state, shard_number)
+        assert isinstance(writer, output_writer_class)
+        output_writers.append(writer)
+    else:
+      output_writers = [None for ir in input_readers]
+
+    state.put(config=util.create_datastore_write_config(spec))
 
     KickOffJobHandler._schedule_shards(
-        spec, input_readers, queue_name, self.base_path())
+        spec, input_readers, output_writers, queue_name, self.base_path())
 
     ControllerCallbackHandler.reschedule(
         self.base_path(), spec, queue_name=queue_name, serial_id=0)
@@ -621,7 +644,12 @@ class KickOffJobHandler(base_handler.TaskQueueHandler):
     return value
 
   @classmethod
-  def _schedule_shards(cls, spec, input_readers, queue_name, base_path):
+  def _schedule_shards(cls,
+                       spec,
+                       input_readers,
+                       output_writers,
+                       queue_name,
+                       base_path):
     """Prepares shard states and schedules their execution.
 
     Args:
@@ -630,24 +658,35 @@ class KickOffJobHandler(base_handler.TaskQueueHandler):
       queue_name: The queue to run this job on.
       base_path: The base url path of mapreduce callbacks.
     """
+    assert len(input_readers) == len(output_writers)
+
+
+
     shard_states = []
     for shard_number, input_reader in enumerate(input_readers):
-      shard = model.ShardState.create_new(spec.mapreduce_id, shard_number)
-      shard.shard_description = str(input_reader)
-      shard_states.append(shard)
+      shard_state = model.ShardState.create_new(spec.mapreduce_id, shard_number)
+      shard_state.shard_description = str(input_reader)
+      shard_states.append(shard_state)
+
 
     existing_shard_states = db.get(shard.key() for shard in shard_states)
     existing_shard_keys = set(shard.key() for shard in existing_shard_states
                               if shard is not None)
 
-    db.put(shard for shard in shard_states
-           if shard.key() not in existing_shard_keys)
 
-    for shard_number, input_reader in enumerate(input_readers):
+    db.put((shard for shard in shard_states
+            if shard.key() not in existing_shard_keys),
+           config=util.create_datastore_write_config(spec))
+
+    for shard_number, (input_reader, output_writer) in enumerate(
+        zip(input_readers, output_writers)):
       shard_id = model.ShardState.shard_id_from_number(
           spec.mapreduce_id, shard_number)
-      MapperWorkerCallbackHandler.schedule_slice(
-          base_path, spec, shard_id, 0, input_reader, queue_name=queue_name)
+      MapperWorkerCallbackHandler._schedule_slice(
+          model.TransientShardState(
+              base_path, spec, shard_id, 0, input_reader,
+              output_writer=output_writer),
+          queue_name=queue_name)
 
 
 class StartJobHandler(base_handler.PostJsonHandler):
@@ -655,24 +694,29 @@ class StartJobHandler(base_handler.PostJsonHandler):
 
   def handle(self):
     """Handles start request."""
+
     mapreduce_name = self._get_required_param("name")
     mapper_input_reader_spec = self._get_required_param("mapper_input_reader")
     mapper_handler_spec = self._get_required_param("mapper_handler")
+    mapper_output_writer_spec = self.request.get("mapper_output_writer")
     mapper_params = self._get_params(
         "mapper_params_validator", "mapper_params.")
     params = self._get_params(
         "params_validator", "params.")
 
+
     mapper_params["processing_rate"] = int(mapper_params.get(
           "processing_rate") or model._DEFAULT_PROCESSING_RATE_PER_SEC)
     queue_name = mapper_params["queue_name"] = mapper_params.get(
         "queue_name", "default")
 
+
     mapper_spec = model.MapperSpec(
         mapper_handler_spec,
         mapper_input_reader_spec,
         mapper_params,
-        int(mapper_params.get("shard_count", model._DEFAULT_SHARD_COUNT)))
+        int(mapper_params.get("shard_count", model._DEFAULT_SHARD_COUNT)),
+        output_writer_spec=mapper_output_writer_spec)
 
     mapreduce_id = type(self)._start_map(
         mapreduce_name,
@@ -738,50 +782,67 @@ class StartJobHandler(base_handler.PostJsonHandler):
                  eta=None,
                  countdown=None,
                  hooks_class_name=None,
-                 _app=None):
+                 _app=None,
+                 transactional=False):
+
     mapper_spec.get_handler()
 
+
     mapper_input_reader_class = mapper_spec.input_reader_class()
     mapper_input_reader_class.validate(mapper_spec)
 
-    state = model.MapreduceState.create_new()
+    mapper_output_writer_class = mapper_spec.output_writer_class()
+    if mapper_output_writer_class:
+      mapper_output_writer_class.validate(mapper_spec)
+
+    mapreduce_id = model.MapreduceState.new_mapreduce_id()
     mapreduce_spec = model.MapreduceSpec(
         name,
-        state.key().id_or_name(),
+        mapreduce_id,
         mapper_spec.to_json(),
         mapreduce_params,
         hooks_class_name)
-    state.mapreduce_spec = mapreduce_spec
-    state.active = True
-    state.active_shards = mapper_spec.shard_count
+
+    kickoff_params = {"mapreduce_spec": mapreduce_spec.to_json_str()}
     if _app:
-      state.app_id = _app
+      kickoff_params["app"] = _app
+    kickoff_worker_task = taskqueue.Task(
+        url=base_path + "/kickoffjob_callback",
+        params=kickoff_params,
+        eta=eta, countdown=countdown)
 
-    state.char_url = ""
-    state.sparkline_url = ""
+    hooks = mapreduce_spec.get_hooks()
+    config = util.create_datastore_write_config(mapreduce_spec)
 
-    def schedule_mapreduce(state, eta, countdown):
-      state.put()
-      kickoff_worker_task = taskqueue.Task(
-          url=base_path + "/kickoffjob_callback",
-          params={"mapreduce_spec": state.mapreduce_spec.to_json_str()},
-          eta=eta, countdown=countdown)
+    def start_mapreduce():
+      if not transactional:
+
+
+
+        state = model.MapreduceState.create_new(mapreduce_spec.mapreduce_id)
+        state.mapreduce_spec = mapreduce_spec
+        state.active = True
+        state.active_shards = mapper_spec.shard_count
+        if _app:
+          state.app_id = _app
+        state.put(config=config)
 
-      hooks = mapreduce_spec.get_hooks()
       if hooks is not None:
         try:
           hooks.enqueue_kickoff_task(kickoff_worker_task, queue_name)
         except NotImplementedError:
+
           pass
         else:
           return
-
       kickoff_worker_task.add(queue_name, transactional=True)
 
-    db.run_in_transaction(
-        schedule_mapreduce, state, eta, countdown)
+    if transactional:
+      start_mapreduce()
+    else:
+      db.run_in_transaction(start_mapreduce)
 
-    return state.key().id_or_name()
+    return mapreduce_id
 
 
 class CleanUpJobHandler(base_handler.PostJsonHandler):
